/*
 * @Author: xiejiang
 * @Date: 2024-12-08 09:25:34
 * @LastEditors: xiejiang
 * @LastEditTime: 2024-12-10 18:05:50
 * @Description:
 * Copyright（c）2024 by 好老师教育科技有限公司 All right Reserved.
 */
import http from '@/api'
import { ReqVersionPage, ResVersionPage, ResVersion, ReqVersion } from '@/api/interface/version/index'

const api = {
  getVersionPage: '/platform/version/dataPage', //  统计并分页查询平台端版本
  getVersionDetail: '/platform/version/detail', // 查询平台端版本详情
  postVersionEdit: '/platform/version/edit', // 修改平台端版本
  postVersionSave: '/platform/version/save', // 新增平台端版本
  postVersionRemove: '/platform/version/remove', // 删除平台端版本
  postVersionEditStatus: '/platform/version/editStatus' // 修改平台端版本状态
}

/**
 * @description  统计并分页查询平台端版本
 * @author 邹琪涛
 * @docs http://api.seevin.com/project/669/interface/api/33176
 * @param page 页码  [必填]
 * @param limit 每页数量（默认为10）
 * @param versionType 终端类型*【1：平台端（后台）；2：机构端；3：】  [必填]
 * @param onlineTime 上线时间*
 * @param status 版本状态*【1：开发中；2：已发布；3：已下线】
 */
export const getVersionPage = (params: ReqVersionPage) => {
  return http.get<ResVersionPage>(api.getVersionPage, params)
}

/**
 * @description 查询平台端版本详情
 * @author 邹琪涛
 * @docs http://api.seevin.com/project/669/interface/api/33177
 * @param versionId 平台端版本id  [必填]
 */
export const getVersionDetail = (params: { versionId: string }) => {
  return http.get<ResVersion>(api.getVersionDetail, params)
}

/**
 * @description 修改平台端版本
 * @author 邹琪涛
 * @docs http://api.seevin.com/project/669/interface/api/33178
 * @param description 更新说明* [必填]
 * @param remark 版本备注 [必填]
 * @param version 版本号* [必填]
 * @param versionId 版本id* [必填]
 * @param versionType 终端类型*【1平台（后台） 2机构】 [必填]
 */
export const postVersionEdit = (data: ReqVersion) => {
  return http.post(api.postVersionEdit, data)
}

/**
 * @description 新增平台端版本
 * @author 邹琪涛
 * @docs http://api.seevin.com/project/669/interface/api/33181
 * @param description 更新说明* [必填]
 * @param remark 版本备注 [必填]
 * @param version 版本号* [必填]
 * @param versionType 终端类型*【1平台（后台） 2机构】 [必填]
 */
export const postVersionSave = (data: ReqVersion) => {
  return http.post(api.postVersionSave, data)
}

/**
 * @description 删除平台端版本
 * @author 邹琪涛
 * @docs http://api.seevin.com/project/669/interface/api/33180
 * @param ids 被删除数据的id列表 [必填]
 */
export const postVersionRemove = (data: { ids: string[] }) => {
  return http.post(api.postVersionRemove, data)
}

/**
 * @description 修改平台端版本状态
 * @author 邹琪涛
 * @docs http://api.seevin.com/project/669/interface/api/33179
 * @param status 版本状态*【1：开发中；2：已发布；3：已下线】 [必填]
 * @param versionId 版本id* [必填]
 */
export const postVersionEditStatus = (data: { status: number; versionId: string }) => {
  return http.post(api.postVersionEditStatus, data)
}
